# PrintJobAlert


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**event_type** | [**EventTypeEnum**](EventTypeEnum.md) |  | 
**event_source** | [**EventSourceEnum**](EventSourceEnum.md) |  | 
**payload** | **dict(str, object)** |  | [optional] 
**email_message_id** | **str** |  | [optional] 
**image** | **str** |  | [optional] 
**user** | **int** |  | [readonly] 
**pi** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


